#! /usr/bin/env python
"""Plots validation of Merchant skeletal mechanisms for n-butanol PSR.
"""
from __future__ import division
import sys
import os.path
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.backends.backend_pdf import PdfPages

home_dir = os.path.join(sys.path[0], '../')
home_dir = os.path.realpath(home_dir)

figures_dir = os.path.join(home_dir, 'figures')
data_dir = os.path.join(home_dir, 'data', 'Merchant-skeletal-PSR-validation')

font = {'weight' : 'normal',
        'size' : 16,
        'family' : 'serif',
        'serif' : ['Times New Roman']}
plt.rc('font', **font)

### n-butanol
# Residence time (s), temperature (K)
data_detailed_1 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-detailed-1atm.txt'), delimiter = ',')
data_detailed_40 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-detailed-40atm.txt'), delimiter = ',')
data_drgep_1 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-DRGEP-1atm.txt'), delimiter = ',')
data_drgep_40 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-DRGEP-40atm.txt'), delimiter = ',')
data_drgepsa_1 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-DRGEPSA-1atm.txt'), delimiter = ',')
data_drgepsa_40 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-DRGEPSA-40atm.txt'), delimiter = ',')

# equivalence ratio = 0.5
data_detailed_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-detailed-1atm-phi0.5.txt'), delimiter = ',')
data_detailed_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-detailed-40atm-phi0.5.txt'), delimiter = ',')
data_drgep_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-DRGEP-1atm-phi0.5.txt'), delimiter = ',')
data_drgep_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-DRGEP-40atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-DRGEPSA-1atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-DRGEPSA-40atm-phi0.5.txt'), delimiter = ',')

# equivalence ratio = 1.5
data_detailed_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-detailed-1atm-phi1.5.txt'), delimiter = ',')
data_detailed_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-detailed-40atm-phi1.5.txt'), delimiter = ',')
data_drgep_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-DRGEP-1atm-phi1.5.txt'), delimiter = ',')
data_drgep_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-DRGEP-40atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-DRGEPSA-1atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-PSR-DRGEPSA-40atm-phi1.5.txt'), delimiter = ',')

# plot masked data to avoid clutter in lower branches

plt.semilogx(data_detailed_1[:,0], np.ma.masked_less(data_detailed_1[:,1], 1500),
             marker='.', linestyle='None', color='black', label='Detailed', markevery=3
             )
plt.semilogx(data_detailed_40[:,0], np.ma.masked_less(data_detailed_40[:,1], 1700),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phip5[:,0], np.ma.masked_less(data_detailed_1_phip5[:,1], 1300),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phip5[:,0], np.ma.masked_less(data_detailed_40_phip5[:,1], 1300),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phi1p5[:,0], np.ma.masked_less(data_detailed_1_phi1p5[:,1], 1600),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phi1p5[:,0], np.ma.masked_less(data_detailed_40_phi1p5[:,1], 1500),
             marker='.', linestyle='None', color='black', markevery=3
             )

plt.semilogx(data_drgep_1[:,0], np.ma.masked_less(data_drgep_1[:,1], 1500),
             linestyle='-', color='blue', label='DRGEP'
             )
plt.semilogx(data_drgep_40[:,0], np.ma.masked_less(data_drgep_40[:,1], 1700),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phip5[:,0], np.ma.masked_less(data_drgep_1_phip5[:,1], 1300),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phip5[:,0], np.ma.masked_less(data_drgep_40_phip5[:,1], 1300),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phi1p5[:,0], np.ma.masked_less(data_drgep_1_phi1p5[:,1], 1600),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phi1p5[:,0], np.ma.masked_less(data_drgep_40_phi1p5[:,1], 1500),
             linestyle='-', color='blue'
             )

plt.semilogx(data_drgepsa_1[:,0], np.ma.masked_less(data_drgepsa_1[:,1], 1500),
             linestyle='--', color='red', label='DRGEPSA'
             )
plt.semilogx(data_drgepsa_40[:,0], np.ma.masked_less(data_drgepsa_40[:,1], 1700),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phip5[:,0], np.ma.masked_less(data_drgepsa_1_phip5[:,1], 1300),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phip5[:,0], np.ma.masked_less(data_drgepsa_40_phip5[:,1], 1300),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phi1p5[:,0], np.ma.masked_less(data_drgepsa_1_phi1p5[:,1], 1600),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phi1p5[:,0], np.ma.masked_less(data_drgepsa_40_phi1p5[:,1], 1500),
             linestyle='--', color='red'
             )

plt.axis((2e-6, 0.9, 1200, 2500))

plt.text(1e-1, 2330, '$\phi$ = 1.0', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )

plt.text(1e-1, 2100, '$\phi$ = 1.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )

plt.text(1e-1, 1670, '$\phi$ = 0.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )

plt.annotate('1 atm', fontsize=16, color='black',
              xytext=(2e-3, 1800), xy=(7e-4, 1440),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(2e-3, 1800), xy=(2.2e-4, 1800),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(2e-3, 1800), xy=(8e-5, 1600),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

plt.annotate('40 atm', fontsize=16, color='black',
              xytext=(1e-5, 1400), xy=(1e-3, 1400),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-5, 1400), xy=(1e-5, 1810),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-5, 1400), xy=(4.4e-5, 1600),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='lower right', prop=leg_font, numpoints=1)
plt.xlabel('Residence time (s)', **axis_font)
plt.ylabel('Temperature (K)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Merchant_nbutanol_skel_PSR.pdf'))
pp.savefig()
pp.close()

plt.clf()

### iso-butanol
# Residence time (s), temperature (K)
data_detailed_1 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-detailed-1atm.txt'), delimiter = ',')
data_detailed_40 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-detailed-40atm.txt'), delimiter = ',')
data_drgep_1 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-DRGEP-1atm.txt'), delimiter = ',')
data_drgep_40 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-DRGEP-40atm.txt'), delimiter = ',')
data_drgepsa_1 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-DRGEPSA-1atm.txt'), delimiter = ',')
data_drgepsa_40 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-DRGEPSA-40atm.txt'), delimiter = ',')

# equivalence ratio = 0.5
data_detailed_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-detailed-1atm-phi0.5.txt'), delimiter = ',')
data_detailed_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-detailed-40atm-phi0.5.txt'), delimiter = ',')
data_drgep_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-DRGEP-1atm-phi0.5.txt'), delimiter = ',')
data_drgep_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-DRGEP-40atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-DRGEPSA-1atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-DRGEPSA-40atm-phi0.5.txt'), delimiter = ',')

# equivalence ratio = 1.5
data_detailed_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-detailed-1atm-phi1.5.txt'), delimiter = ',')
data_detailed_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-detailed-40atm-phi1.5.txt'), delimiter = ',')
data_drgep_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-DRGEP-1atm-phi1.5.txt'), delimiter = ',')
data_drgep_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-DRGEP-40atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-DRGEPSA-1atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-PSR-DRGEPSA-40atm-phi1.5.txt'), delimiter = ',')

# plot masked data to avoid clutter in lower branches
plt.semilogx(data_detailed_1[:,0],
             np.ma.masked_less(data_detailed_1[:,1], 1500),
             marker='.', linestyle='None', color='black', label='Detailed', markevery=3
             )
plt.semilogx(data_detailed_40[:,0],
             np.ma.masked_less(data_detailed_40[:,1], 1800),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phip5[:,0],
             np.ma.masked_less(data_detailed_1_phip5[:,1], 1300),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phip5[:,0],
             np.ma.masked_less(data_detailed_40_phip5[:,1], 1200),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phi1p5[:,0],
             np.ma.masked_less(data_detailed_1_phi1p5[:,1], 1600),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phi1p5[:,0],
             np.ma.masked_less(data_detailed_40_phi1p5[:,1], 1500),
             marker='.', linestyle='None', color='black', markevery=3
             )

plt.semilogx(data_drgep_1[:,0],
             np.ma.masked_less(data_drgep_1[:,1], 1500),
             linestyle='-', color='blue', label='DRGEP'
             )
plt.semilogx(data_drgep_40[:,0],
             np.ma.masked_less(data_drgep_40[:,1], 1800),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phip5[:,0],
             np.ma.masked_less(data_drgep_1_phip5[:,1], 1300),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phip5[:,0],
             np.ma.masked_less(data_drgep_40_phip5[:,1], 1200),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phi1p5[:,0],
             np.ma.masked_less(data_drgep_1_phi1p5[:,1], 1600),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phi1p5[:,0],
             np.ma.masked_less(data_drgep_40_phi1p5[:,1], 1500),
             linestyle='-', color='blue'
             )

plt.semilogx(data_drgepsa_1[:,0],
             np.ma.masked_less(data_drgepsa_1[:,1], 1500),
             linestyle='--', color='red', label='DRGEPSA'
             )
plt.semilogx(data_drgepsa_40[:,0],
             np.ma.masked_less(data_drgepsa_40[:,1], 1800),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phip5[:,0],
             np.ma.masked_less(data_drgepsa_1_phip5[:,1], 1300),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phip5[:,0],
             np.ma.masked_less(data_drgepsa_40_phip5[:,1], 1200),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phi1p5[:,0],
             np.ma.masked_less(data_drgepsa_1_phi1p5[:,1], 1600),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phi1p5[:,0],
             np.ma.masked_less(data_drgepsa_40_phi1p5[:,1], 1500),
             linestyle='--', color='red'
             )

plt.axis((2e-6, 0.8, 1200, 2500))

plt.text(1e-1, 2330, '$\phi$ = 1.0', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )
plt.text(1e-1, 1640, '$\phi$ = 0.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )
plt.text(1e-1, 2090, '$\phi$ = 1.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )

plt.annotate('1 atm', fontsize=16, color='black',
              xytext=(2e-3, 1700), xy=(3e-4, 1700),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(2e-3, 1700), xy=(2e-4, 1550),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(2e-3, 1700), xy=(9e-4, 1470),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

plt.annotate('40 atm', fontsize=16, color='black',
              xytext=(1e-5, 1400), xy=(1.4e-3, 1400),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-5, 1400), xy=(1.e-5, 1875),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-5, 1400), xy=(6e-5, 1600),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='lower right', prop=leg_font, numpoints=1)
plt.xlabel('Residence time (s)', **axis_font)
plt.ylabel('Temperature (K)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Merchant_isobutanol_skel_PSR.pdf'))
pp.savefig()
pp.close()

plt.clf()

### sec-butanol
# Residence time (s), temperature (K)
data_detailed_1 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-detailed-1atm.txt'), delimiter = ',')
data_detailed_40 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-detailed-40atm.txt'), delimiter = ',')
data_drgep_1 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-DRGEP-1atm.txt'), delimiter = ',')
data_drgep_40 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-DRGEP-40atm.txt'), delimiter = ',')
data_drgepsa_1 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-DRGEPSA-1atm.txt'), delimiter = ',')
data_drgepsa_40 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-DRGEPSA-40atm.txt'), delimiter = ',')

# equivalence ratio = 0.5
data_detailed_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-detailed-1atm-phi0.5.txt'), delimiter = ',')
data_detailed_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-detailed-40atm-phi0.5.txt'), delimiter = ',')
data_drgep_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-DRGEP-1atm-phi0.5.txt'), delimiter = ',')
data_drgep_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-DRGEP-40atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-DRGEPSA-1atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-DRGEPSA-40atm-phi0.5.txt'), delimiter = ',')

# equivalence ratio = 1.5
data_detailed_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-detailed-1atm-phi1.5.txt'), delimiter = ',')
data_detailed_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-detailed-40atm-phi1.5.txt'), delimiter = ',')
data_drgep_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-DRGEP-1atm-phi1.5.txt'), delimiter = ',')
data_drgep_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-DRGEP-40atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-DRGEPSA-1atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-PSR-DRGEPSA-40atm-phi1.5.txt'), delimiter = ',')


# plot masked data to avoid clutter in lower branches
plt.semilogx(data_detailed_1[:,0],
             np.ma.masked_less(data_detailed_1[:,1], 1500),
             marker='.', linestyle='None', color='black', label='Detailed', markevery=3
             )
plt.semilogx(data_detailed_40[:,0],
             np.ma.masked_less(data_detailed_40[:,1], 1600),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phip5[:,0],
             np.ma.masked_less(data_detailed_1_phip5[:,1], 1300),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phip5[:,0],
             np.ma.masked_less(data_detailed_40_phip5[:,1], 1200),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phi1p5[:,0],
             np.ma.masked_less(data_detailed_1_phi1p5[:,1], 1600),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phi1p5[:,0],
             np.ma.masked_less(data_detailed_40_phi1p5[:,1], 1400),
             marker='.', linestyle='None', color='black', markevery=3
             )

plt.semilogx(data_drgep_1[:,0],
             np.ma.masked_less(data_drgep_1[:,1], 1500),
             linestyle='-', color='blue', label='DRGEP'
             )
plt.semilogx(data_drgep_40[:,0],
             np.ma.masked_less(data_drgep_40[:,1], 1600),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phip5[:,0],
             np.ma.masked_less(data_drgep_1_phip5[:,1], 1300),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phip5[:,0],
             np.ma.masked_less(data_drgep_40_phip5[:,1], 1200),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phi1p5[:,0],
             np.ma.masked_less(data_drgep_1_phi1p5[:,1], 1600),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phi1p5[:,0],
             np.ma.masked_less(data_drgep_40_phi1p5[:,1], 1400),
             linestyle='-', color='blue'
             )

plt.semilogx(data_drgepsa_1[:,0],
             np.ma.masked_less(data_drgepsa_1[:,1], 1500),
             linestyle='--', color='red', label='DRGEPSA'
             )
plt.semilogx(data_drgepsa_40[:,0],
             np.ma.masked_less(data_drgepsa_40[:,1], 1600),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phip5[:,0],
             np.ma.masked_less(data_drgepsa_1_phip5[:,1], 1300),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phip5[:,0],
             np.ma.masked_less(data_drgepsa_40_phip5[:,1], 1200),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phi1p5[:,0],
             np.ma.masked_less(data_drgepsa_1_phi1p5[:,1], 1600),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phi1p5[:,0],
             np.ma.masked_less(data_drgepsa_40_phi1p5[:,1], 1400),
             linestyle='--', color='red'
             )

plt.axis((2e-6, 0.8, 1250, 2500))

plt.text(1e-1, 2340, '$\phi$ = 1.0', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )
plt.text(1e-1, 1640, '$\phi$ = 0.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )
plt.text(1e-1, 2080, '$\phi$ = 1.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )

plt.annotate('1 atm', fontsize=16, color='black',
              xytext=(2e-3, 1700), xy=(5.4e-4, 1700),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(2e-3, 1700), xy=(1e-3, 1465),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(2e-3, 1700), xy=(2e-4, 1540),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

plt.annotate('40 atm', fontsize=16, color='black',
              xytext=(1e-5, 1400), xy=(1e-5, 1830),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-5, 1400), xy=(1.5e-3, 1400),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-5, 1400), xy=(1e-4, 1530),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='lower right', prop=leg_font, numpoints=1)
plt.xlabel('Residence time (s)', **axis_font)
plt.ylabel('Temperature (K)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Merchant_secbutanol_skel_PSR.pdf'))
pp.savefig()
pp.close()

plt.clf()

### tert-butanol
# Residence time (s), temperature (K)
data_detailed_1 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-detailed-1atm.txt'), delimiter = ',')
data_detailed_40 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-detailed-40atm.txt'), delimiter = ',')
data_drgep_1 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-DRGEP-1atm.txt'), delimiter = ',')
data_drgep_40 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-DRGEP-40atm.txt'), delimiter = ',')
data_drgepsa_1 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-DRGEPSA-1atm.txt'), delimiter = ',')
data_drgepsa_40 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-DRGEPSA-40atm.txt'), delimiter = ',')

# equivalence ratio = 0.5
data_detailed_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-detailed-1atm-phi0.5.txt'), delimiter = ',')
data_detailed_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-detailed-40atm-phi0.5.txt'), delimiter = ',')
data_drgep_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-DRGEP-1atm-phi0.5.txt'), delimiter = ',')
data_drgep_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-DRGEP-40atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-DRGEPSA-1atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-DRGEPSA-40atm-phi0.5.txt'), delimiter = ',')

# equivalence ratio = 1.5
data_detailed_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-detailed-1atm-phi1.5.txt'), delimiter = ',')
data_detailed_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-detailed-40atm-phi1.5.txt'), delimiter = ',')
data_drgep_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-DRGEP-1atm-phi1.5.txt'), delimiter = ',')
data_drgep_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-DRGEP-40atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-DRGEPSA-1atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-PSR-DRGEPSA-40atm-phi1.5.txt'), delimiter = ',')


# plot masked data to avoid clutter in lower branches
plt.semilogx(data_detailed_1[:,0],
             np.ma.masked_less(data_detailed_1[:,1], 1500),
             marker='.', linestyle='None', color='black', label='Detailed', markevery=3
             )
plt.semilogx(data_detailed_40[:,0],
             np.ma.masked_less(data_detailed_40[:,1], 1700),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phip5[:,0],
             np.ma.masked_less(data_detailed_1_phip5[:,1], 1300),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phip5[:,0],
             np.ma.masked_less(data_detailed_40_phip5[:,1], 1200),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phi1p5[:,0],
             np.ma.masked_less(data_detailed_1_phi1p5[:,1], 1600),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phi1p5[:,0],
             np.ma.masked_less(data_detailed_40_phi1p5[:,1], 1400),
             marker='.', linestyle='None', color='black', markevery=3
             )

plt.semilogx(data_drgep_1[:,0],
             np.ma.masked_less(data_drgep_1[:,1], 1500),
             linestyle='-', color='blue', label='DRGEP'
             )
plt.semilogx(data_drgep_40[:,0],
             np.ma.masked_less(data_drgep_40[:,1], 1700),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phip5[:,0],
             np.ma.masked_less(data_drgep_1_phip5[:,1], 1300),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phip5[:,0],
             np.ma.masked_less(data_drgep_40_phip5[:,1], 1200),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phi1p5[:,0],
             np.ma.masked_less(data_drgep_1_phi1p5[:,1], 1600),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phi1p5[:,0],
             np.ma.masked_less(data_drgep_40_phi1p5[:,1], 1400),
             linestyle='-', color='blue'
             )

plt.semilogx(data_drgepsa_1[:,0],
             np.ma.masked_less(data_drgepsa_1[:,1], 1500),
             linestyle='--', color='red', label='DRGEPSA'
             )
plt.semilogx(data_drgepsa_40[:,0],
             np.ma.masked_less(data_drgepsa_40[:,1], 1700),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phip5[:,0],
             np.ma.masked_less(data_drgepsa_1_phip5[:,1], 1300),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phip5[:,0],
             np.ma.masked_less(data_drgepsa_40_phip5[:,1], 1200),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phi1p5[:,0],
             np.ma.masked_less(data_drgepsa_1_phi1p5[:,1], 1600),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phi1p5[:,0],
             np.ma.masked_less(data_drgepsa_40_phi1p5[:,1], 1400),
             linestyle='--', color='red'
             )

plt.axis((3e-6, 0.8, 1250, 2500))

plt.text(1e-1, 2320, '$\phi$ = 1.0', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )
plt.text(1e-1, 1625, '$\phi$ = 0.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )
plt.text(1e-1, 2065, '$\phi$ = 1.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )

plt.annotate('1 atm', fontsize=16, color='black',
              xytext=(1e-2, 1750), xy=(1e-3, 1750),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-2, 1750), xy=(4e-4, 1550),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-2, 1750), xy=(1.2e-3, 1470),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

plt.annotate('40 atm', fontsize=16, color='black',
              xytext=(1.2e-5, 1500), xy=(1.2e-5, 1930),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1.2e-5, 1500), xy=(2e-4, 1500),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1.2e-5, 1500), xy=(2e-3, 1380),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='lower right', prop=leg_font, numpoints=1)
plt.xlabel('Residence time (s)', **axis_font)
plt.ylabel('Temperature (K)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Merchant_tertbutanol_skel_PSR.pdf'))
pp.savefig()
pp.close()
