#! /usr/bin/env python
"""Plots laminar flame speed validation of Merchant skeletal mechanisms for butanols.
"""
from __future__ import division
import sys
import os.path
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.backends.backend_pdf import PdfPages

home_dir = os.path.join(sys.path[0], '../')
home_dir = os.path.realpath(home_dir)

figures_dir = os.path.join(home_dir, 'figures')
data_dir = os.path.join(home_dir, 'data', 'Merchant-skeletal-flamespeed-validation')

font = {'weight' : 'normal',
        'size' : 16,
        'family' : 'serif',
        'serif' : ['Times New Roman']}
plt.rc('font', **font)

### n-butanol
# Equivalence ratio, 1 atm, 20 atm, 40 atm
data_detailed = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-flamespeed-detailed.txt'), delimiter = ',')
data_drgep = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-flamespeed-DRGEP.txt'), delimiter = ',')
data_drgepsa = np.genfromtxt(os.path.join(data_dir, 'Merchant-nbutanol-flamespeed-DRGEPSA.txt'), delimiter = ',')

plt.plot(data_detailed[:,0], data_detailed[:,1], marker='o', linestyle='None', color='black', label='Detailed')
plt.plot(data_detailed[:,0], data_detailed[:,2], marker='p', linestyle='None', color='black')
plt.plot(data_detailed[:,0], data_detailed[:,3], marker='p', linestyle='None', color='black')

plt.plot(data_drgep[:,0], data_drgep[:,1], linestyle='-', color='blue', label='DRGEP')
plt.plot(data_drgep[:,0], data_drgep[:,2], linestyle='-', color='blue')
plt.plot(data_drgep[:,0], data_drgep[:,3], linestyle='-', color='blue')

plt.plot(data_drgepsa[:,0], data_drgepsa[:,1], linestyle='--', color='red', label='DRGEPSA')
plt.plot(data_drgepsa[:,0], data_drgepsa[:,2], linestyle='--', color='red')
plt.plot(data_drgepsa[:,0], data_drgepsa[:,3], linestyle='--', color='red')

plt.text(1.0, 56, '1 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(1.0, 30, '20 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(1.0, 14, '40 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')

plt.axis((0.55, 1.65, 0., 75.))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='upper right', prop=leg_font, numpoints=1)
plt.xlabel(u'Equivalence ratio, $\phi$', **axis_font)
plt.ylabel('Laminar flame speed (cm/s)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Merchant_nbutanol_skel_flamespeed.pdf'))
pp.savefig()
pp.close()

plt.clf()

### iso-butanol
# Equivalence ratio, 1 atm, 20 atm, 40 atm
data_detailed = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-flamespeed-detailed.txt'), delimiter = ',')
data_drgep = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-flamespeed-DRGEP.txt'), delimiter = ',')
data_drgepsa = np.genfromtxt(os.path.join(data_dir, 'Merchant-isobutanol-flamespeed-DRGEPSA.txt'), delimiter = ',')

plt.plot(data_detailed[:,0], data_detailed[:,1], marker='o', linestyle='None', color='black', label='Detailed')
plt.plot(data_detailed[:,0], data_detailed[:,2], marker='p', linestyle='None', color='black')
plt.plot(data_detailed[:,0], data_detailed[:,3], marker='p', linestyle='None', color='black')

plt.plot(data_drgep[:,0], data_drgep[:,1], linestyle='-', color='blue', label='DRGEP')
plt.plot(data_drgep[:,0], data_drgep[:,2], linestyle='-', color='blue')
plt.plot(data_drgep[:,0], data_drgep[:,3], linestyle='-', color='blue')

plt.plot(data_drgepsa[:,0], data_drgepsa[:,1], linestyle='--', color='red', label='DRGEPSA')
plt.plot(data_drgepsa[:,0], data_drgepsa[:,2], linestyle='--', color='red')
plt.plot(data_drgepsa[:,0], data_drgepsa[:,3], linestyle='--', color='red')

plt.text(1.0, 55, '1 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(1.0, 28, '20 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(1.0, 15, '40 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')

plt.axis((0.55, 1.65, 0., 75.))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='upper right', prop=leg_font, numpoints=1)
plt.xlabel(u'Equivalence ratio, $\phi$', **axis_font)
plt.ylabel('Laminar flame speed (cm/s)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Merchant_isobutanol_skel_flamespeed.pdf'))
pp.savefig()
pp.close()

plt.clf()

### sec-butanol
# Equivalence ratio, 1 atm, 20 atm, 40 atm
data_detailed = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-flamespeed-detailed.txt'), delimiter = ',')
data_drgep = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-flamespeed-DRGEP.txt'), delimiter = ',')
data_drgepsa = np.genfromtxt(os.path.join(data_dir, 'Merchant-secbutanol-flamespeed-DRGEPSA.txt'), delimiter = ',')

plt.plot(data_detailed[:,0], data_detailed[:,1], marker='o', linestyle='None', color='black', label='Detailed')
plt.plot(data_detailed[:,0], data_detailed[:,2], marker='p', linestyle='None', color='black')
plt.plot(data_detailed[:,0], data_detailed[:,3], marker='p', linestyle='None', color='black')

plt.plot(data_drgep[:,0], data_drgep[:,1], linestyle='-', color='blue', label='DRGEP')
plt.plot(data_drgep[:,0], data_drgep[:,2], linestyle='-', color='blue')
plt.plot(data_drgep[:,0], data_drgep[:,3], linestyle='-', color='blue')

plt.plot(data_drgepsa[:,0], data_drgepsa[:,1], linestyle='--', color='red', label='DRGEPSA')
plt.plot(data_drgepsa[:,0], data_drgepsa[:,2], linestyle='--', color='red')
plt.plot(data_drgepsa[:,0], data_drgepsa[:,3], linestyle='--', color='red')

plt.text(1.0, 52, '1 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(1.0, 28, '20 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(1.0, 12, '40 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')

plt.axis((0.55, 1.65, 0., 75.))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='upper right', prop=leg_font, numpoints=1)
plt.xlabel(u'Equivalence ratio, $\phi$', **axis_font)
plt.ylabel('Laminar flame speed (cm/s)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Merchant_secbutanol_skel_flamespeed.pdf'))
pp.savefig()
pp.close()

plt.clf()

### tert-butanol
# Equivalence ratio, 1 atm, 20 atm, 40 atm
data_detailed = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-flamespeed-detailed.txt'), delimiter = ',')
data_drgep = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-flamespeed-DRGEP.txt'), delimiter = ',')
data_drgepsa = np.genfromtxt(os.path.join(data_dir, 'Merchant-tertbutanol-flamespeed-DRGEPSA.txt'), delimiter = ',')

plt.plot(data_detailed[:,0], data_detailed[:,1], marker='o', linestyle='None', color='black', label='Detailed')
plt.plot(data_detailed[:,0], data_detailed[:,2], marker='p', linestyle='None', color='black')
plt.plot(data_detailed[:,0], data_detailed[:,3], marker='p', linestyle='None', color='black')

plt.plot(data_drgep[:,0], data_drgep[:,1], linestyle='-', color='blue', label='DRGEP')
plt.plot(data_drgep[:,0], data_drgep[:,2], linestyle='-', color='blue')
plt.plot(data_drgep[:,0], data_drgep[:,3], linestyle='-', color='blue')

plt.plot(data_drgepsa[:,0], data_drgepsa[:,1], linestyle='--', color='red', label='DRGEPSA')
plt.plot(data_drgepsa[:,0], data_drgepsa[:,2], linestyle='--', color='red')
plt.plot(data_drgepsa[:,0], data_drgepsa[:,3], linestyle='--', color='red')

plt.text(1.0, 48, '1 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(1.0, 24, '20 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(1.0, 10, '40 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')

plt.axis((0.55, 1.65, 0., 75.))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='upper right', prop=leg_font, numpoints=1)
plt.xlabel(u'Equivalence ratio, $\phi$', **axis_font)
plt.ylabel('Laminar flame speed (cm/s)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Merchant_tertbutanol_skel_flamespeed.pdf'))
pp.savefig()
pp.close()
