#! /usr/bin/env python
"""Plots validation of Sarathy skeletal mechanisms for n-butanol PSR.
"""
from __future__ import division
import sys
import os.path
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.backends.backend_pdf import PdfPages

home_dir = os.path.join(sys.path[0], '../')
home_dir = os.path.realpath(home_dir)

figures_dir = os.path.join(home_dir, 'figures')
data_dir = os.path.join(home_dir, 'data', 'Sarathy-skeletal-PSR-validation')

font = {'weight' : 'normal',
        'size' : 16,
        'family' : 'serif',
        'serif' : ['Times New Roman']}
plt.rc('font', **font)

### n-butanol
# Residence time (s), temperature (K)
data_detailed_1 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-detailed-1atm.txt'), delimiter = ',')
data_detailed_40 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-detailed-40atm.txt'), delimiter = ',')
data_drgep_1 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-DRGEP-1atm.txt'), delimiter = ',')
data_drgep_40 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-DRGEP-40atm.txt'), delimiter = ',')
data_drgepsa_1 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-DRGEPSA-1atm.txt'), delimiter = ',')
data_drgepsa_40 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-DRGEPSA-40atm.txt'), delimiter = ',')

# equivalence ratio = 0.5
data_detailed_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-detailed-1atm-phi0.5.txt'), delimiter = ',')
data_detailed_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-detailed-40atm-phi0.5.txt'), delimiter = ',')
data_drgep_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-DRGEP-1atm-phi0.5.txt'), delimiter = ',')
data_drgep_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-DRGEP-40atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-DRGEPSA-1atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-DRGEPSA-40atm-phi0.5.txt'), delimiter = ',')

# equivalence ratio = 1.5
data_detailed_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-detailed-1atm-phi1.5.txt'), delimiter = ',')
data_detailed_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-detailed-40atm-phi1.5.txt'), delimiter = ',')
data_drgep_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-DRGEP-1atm-phi1.5.txt'), delimiter = ',')
data_drgep_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-DRGEP-40atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-DRGEPSA-1atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-PSR-DRGEPSA-40atm-phi1.5.txt'), delimiter = ',')

# plot masked data to avoid clutter in lower branches

plt.semilogx(data_detailed_1[:,0], np.ma.masked_less(data_detailed_1[:,1], 1500),
             marker='.', linestyle='None', color='black', label='Detailed', markevery=3
             )
plt.semilogx(data_detailed_40[:,0], np.ma.masked_less(data_detailed_40[:,1], 1700),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phip5[:,0], np.ma.masked_less(data_detailed_1_phip5[:,1], 1300),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phip5[:,0], np.ma.masked_less(data_detailed_40_phip5[:,1], 1200),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phi1p5[:,0], np.ma.masked_less(data_detailed_1_phi1p5[:,1], 1500),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phi1p5[:,0], np.ma.masked_less(data_detailed_40_phi1p5[:,1], 1450),
             marker='.', linestyle='None', color='black', markevery=3
             )

plt.semilogx(data_drgep_1[:,0], np.ma.masked_less(data_drgep_1[:,1], 1500),
             linestyle='-', color='blue', label='DRGEP'
             )
plt.semilogx(data_drgep_40[:,0], np.ma.masked_less(data_drgep_40[:,1], 1700),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phip5[:,0], np.ma.masked_less(data_drgep_1_phip5[:,1], 1300),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phip5[:,0], np.ma.masked_less(data_drgep_40_phip5[:,1], 1200),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phi1p5[:,0], np.ma.masked_less(data_drgep_1_phi1p5[:,1], 1500),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phi1p5[:,0], np.ma.masked_less(data_drgep_40_phi1p5[:,1], 1450),
             linestyle='-', color='blue'
             )

plt.semilogx(data_drgepsa_1[:,0], np.ma.masked_less(data_drgepsa_1[:,1], 1500),
             linestyle='--', color='red', label='DRGEPSA'
             )
plt.semilogx(data_drgepsa_40[:,0], np.ma.masked_less(data_drgepsa_40[:,1], 1700),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phip5[:,0], np.ma.masked_less(data_drgepsa_1_phip5[:,1], 1300),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phip5[:,0], np.ma.masked_less(data_drgepsa_40_phip5[:,1], 1200),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phi1p5[:,0], np.ma.masked_less(data_drgepsa_1_phi1p5[:,1], 1500),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phi1p5[:,0], np.ma.masked_less(data_drgepsa_40_phi1p5[:,1], 1450),
             linestyle='--', color='red'
             )

plt.axis((2e-6, 0.9, 1200, 2500))

plt.text(1e-1, 2345, '$\phi$ = 1.0', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )

plt.text(1e-1, 2100, '$\phi$ = 1.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )

plt.text(1e-1, 1650, '$\phi$ = 0.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )

plt.annotate('1 atm', fontsize=16, color='black',
              xytext=(1e-3, 1700), xy=(1e-4, 1590),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-3, 1700), xy=(3e-4, 1585),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-3, 1700), xy=(1e-3, 1475),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

plt.annotate('40 atm', fontsize=16, color='black',
              xytext=(1e-5, 1400), xy=(1e-5, 1850),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-5, 1400), xy=(5e-5, 1580),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-5, 1400), xy=(2.2e-3, 1440),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='lower right', prop=leg_font, numpoints=1)
plt.xlabel('Residence time (s)', **axis_font)
plt.ylabel('Temperature (K)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Sarathy_nbutanol_skel_PSR.pdf'))
pp.savefig()
pp.close()

plt.clf()

### iso-butanol
# Residence time (s), temperature (K)
data_detailed_1 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-detailed-1atm.txt'), delimiter = ',')
data_detailed_40 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-detailed-40atm.txt'), delimiter = ',')
data_drgep_1 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-DRGEP-1atm.txt'), delimiter = ',')
data_drgep_40 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-DRGEP-40atm.txt'), delimiter = ',')
data_drgepsa_1 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-DRGEPSA-1atm.txt'), delimiter = ',')
data_drgepsa_40 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-DRGEPSA-40atm.txt'), delimiter = ',')

# equivalence ratio = 0.5
data_detailed_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-detailed-1atm-phi0.5.txt'), delimiter = ',')
data_detailed_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-detailed-40atm-phi0.5.txt'), delimiter = ',')
data_drgep_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-DRGEP-1atm-phi0.5.txt'), delimiter = ',')
data_drgep_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-DRGEP-40atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-DRGEPSA-1atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-DRGEPSA-40atm-phi0.5.txt'), delimiter = ',')

# equivalence ratio = 1.5
data_detailed_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-detailed-1atm-phi1.5.txt'), delimiter = ',')
data_detailed_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-detailed-40atm-phi1.5.txt'), delimiter = ',')
data_drgep_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-DRGEP-1atm-phi1.5.txt'), delimiter = ',')
data_drgep_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-DRGEP-40atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-DRGEPSA-1atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-PSR-DRGEPSA-40atm-phi1.5.txt'), delimiter = ',')

# plot masked data to avoid clutter in lower branches
plt.semilogx(data_detailed_1[:,0],
             np.ma.masked_less(data_detailed_1[:,1], 1500),
             marker='.', linestyle='None', color='black', label='Detailed', markevery=3
             )
plt.semilogx(data_detailed_40[:,0],
             np.ma.masked_less(data_detailed_40[:,1], 1700),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phip5[:,0],
             np.ma.masked_less(data_detailed_1_phip5[:,1], 1350),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phip5[:,0],
             np.ma.masked_less(data_detailed_40_phip5[:,1], 1200),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phi1p5[:,0],
             np.ma.masked_less(data_detailed_1_phi1p5[:,1], 1600),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phi1p5[:,0],
             np.ma.masked_less(data_detailed_40_phi1p5[:,1], 1400),
             marker='.', linestyle='None', color='black', markevery=3
             )

plt.semilogx(data_drgep_1[:,0],
             np.ma.masked_less(data_drgep_1[:,1], 1500),
             linestyle='-', color='blue', label='DRGEP'
             )
plt.semilogx(data_drgep_40[:,0],
             np.ma.masked_less(data_drgep_40[:,1], 1700),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phip5[:,0],
             np.ma.masked_less(data_drgep_1_phip5[:,1], 1350),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phip5[:,0],
             np.ma.masked_less(data_drgep_40_phip5[:,1], 1200),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phi1p5[:,0],
             np.ma.masked_less(data_drgep_1_phi1p5[:,1], 1600),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phi1p5[:,0],
             np.ma.masked_less(data_drgep_40_phi1p5[:,1], 1400),
             linestyle='-', color='blue'
             )

plt.semilogx(data_drgepsa_1[:,0],
             np.ma.masked_less(data_drgepsa_1[:,1], 1500),
             linestyle='--', color='red', label='DRGEPSA'
             )
plt.semilogx(data_drgepsa_40[:,0],
             np.ma.masked_less(data_drgepsa_40[:,1], 1700),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phip5[:,0],
             np.ma.masked_less(data_drgepsa_1_phip5[:,1], 1350),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phip5[:,0],
             np.ma.masked_less(data_drgepsa_40_phip5[:,1], 1200),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phi1p5[:,0],
             np.ma.masked_less(data_drgepsa_1_phi1p5[:,1], 1600),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phi1p5[:,0],
             np.ma.masked_less(data_drgepsa_40_phi1p5[:,1], 1400),
             linestyle='--', color='red'
             )

plt.axis((2e-6, 0.8, 1200, 2500))

plt.text(1e-1, 2340, '$\phi$ = 1.0', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )
plt.text(1e-1, 1650, '$\phi$ = 0.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )
plt.text(1e-1, 2100, '$\phi$ = 1.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )

plt.annotate('1 atm', fontsize=16, color='black',
              xytext=(2e-3, 1700), xy=(2e-3, 1518),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(2e-3, 1700), xy=(3e-4, 1700),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(2e-3, 1700), xy=(4.5e-4, 1512),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

plt.annotate('40 atm', fontsize=16, color='black',
              xytext=(1e-5, 1300), xy=(3.3e-3, 1300),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-5, 1300), xy=(2.3e-5, 1800),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-5, 1300), xy=(8e-5, 1565),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='lower right', prop=leg_font, numpoints=1)
plt.xlabel('Residence time (s)', **axis_font)
plt.ylabel('Temperature (K)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Sarathy_isobutanol_skel_PSR.pdf'))
pp.savefig()
pp.close()

plt.clf()

### sec-butanol
# Residence time (s), temperature (K)
data_detailed_1 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-detailed-1atm.txt'), delimiter = ',')
data_detailed_40 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-detailed-40atm.txt'), delimiter = ',')
data_drgep_1 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-DRGEP-1atm.txt'), delimiter = ',')
data_drgep_40 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-DRGEP-40atm.txt'), delimiter = ',')
data_drgepsa_1 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-DRGEPSA-1atm.txt'), delimiter = ',')
data_drgepsa_40 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-DRGEPSA-40atm.txt'), delimiter = ',')

# equivalence ratio = 0.5
data_detailed_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-detailed-1atm-phi0.5.txt'), delimiter = ',')
data_detailed_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-detailed-40atm-phi0.5.txt'), delimiter = ',')
data_drgep_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-DRGEP-1atm-phi0.5.txt'), delimiter = ',')
data_drgep_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-DRGEP-40atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-DRGEPSA-1atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-DRGEPSA-40atm-phi0.5.txt'), delimiter = ',')

# equivalence ratio = 1.5
data_detailed_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-detailed-1atm-phi1.5.txt'), delimiter = ',')
data_detailed_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-detailed-40atm-phi1.5.txt'), delimiter = ',')
data_drgep_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-DRGEP-1atm-phi1.5.txt'), delimiter = ',')
data_drgep_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-DRGEP-40atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-DRGEPSA-1atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-PSR-DRGEPSA-40atm-phi1.5.txt'), delimiter = ',')


# plot masked data to avoid clutter in lower branches
plt.semilogx(data_detailed_1[:,0],
             np.ma.masked_less(data_detailed_1[:,1], 1500),
             marker='.', linestyle='None', color='black', label='Detailed', markevery=3
             )
plt.semilogx(data_detailed_40[:,0],
             np.ma.masked_less(data_detailed_40[:,1], 1700),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phip5[:,0],
             np.ma.masked_less(data_detailed_1_phip5[:,1], 1300),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phip5[:,0],
             np.ma.masked_less(data_detailed_40_phip5[:,1], 1200),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phi1p5[:,0],
             np.ma.masked_less(data_detailed_1_phi1p5[:,1], 1600),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phi1p5[:,0],
             np.ma.masked_less(data_detailed_40_phi1p5[:,1], 1600),
             marker='.', linestyle='None', color='black', markevery=3
             )

plt.semilogx(data_drgep_1[:,0],
             np.ma.masked_less(data_drgep_1[:,1], 1500),
             linestyle='-', color='blue', label='DRGEP'
             )
plt.semilogx(data_drgep_40[:,0],
             np.ma.masked_less(data_drgep_40[:,1], 1700),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phip5[:,0],
             np.ma.masked_less(data_drgep_1_phip5[:,1], 1300),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phip5[:,0],
             np.ma.masked_less(data_drgep_40_phip5[:,1], 1200),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phi1p5[:,0],
             np.ma.masked_less(data_drgep_1_phi1p5[:,1], 1600),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phi1p5[:,0],
             np.ma.masked_less(data_drgep_40_phi1p5[:,1], 1600),
             linestyle='-', color='blue'
             )

plt.semilogx(data_drgepsa_1[:,0],
             np.ma.masked_less(data_drgepsa_1[:,1], 1500),
             linestyle='--', color='red', label='DRGEPSA'
             )
plt.semilogx(data_drgepsa_40[:,0],
             np.ma.masked_less(data_drgepsa_40[:,1], 1700),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phip5[:,0],
             np.ma.masked_less(data_drgepsa_1_phip5[:,1], 1300),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phip5[:,0],
             np.ma.masked_less(data_drgepsa_40_phip5[:,1], 1200),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phi1p5[:,0],
             np.ma.masked_less(data_drgepsa_1_phi1p5[:,1], 1600),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phi1p5[:,0],
             np.ma.masked_less(data_drgepsa_40_phi1p5[:,1], 1600),
             linestyle='--', color='red'
             )

plt.axis((2e-6, 0.8, 1250, 2500))

plt.text(1e-1, 2340, '$\phi$ = 1.0', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )
plt.text(1e-1, 1630, '$\phi$ = 0.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )
plt.text(1e-1, 2070, '$\phi$ = 1.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )

plt.annotate('1 atm', fontsize=16, color='black',
              xytext=(1e-3, 1700), xy=(1e-3, 1470),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-3, 1700), xy=(2e-4, 1700),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-3, 1700), xy=(1e-4, 1600),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

plt.annotate('40 atm', fontsize=16, color='black',
              xytext=(1e-5, 1500), xy=(1.6e-5, 1800),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-5, 1500), xy=(5.0e-5, 1682),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(1e-5, 1500), xy=(3e-3, 1400),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='lower right', prop=leg_font, numpoints=1)
plt.xlabel('Residence time (s)', **axis_font)
plt.ylabel('Temperature (K)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Sarathy_secbutanol_skel_PSR.pdf'))
pp.savefig()
pp.close()

plt.clf()

### tert-butanol
# Residence time (s), temperature (K)
data_detailed_1 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-detailed-1atm.txt'), delimiter = ',')
data_detailed_40 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-detailed-40atm.txt'), delimiter = ',')
data_drgep_1 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-DRGEP-1atm.txt'), delimiter = ',')
data_drgep_40 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-DRGEP-40atm.txt'), delimiter = ',')
data_drgepsa_1 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-DRGEPSA-1atm.txt'), delimiter = ',')
data_drgepsa_40 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-DRGEPSA-40atm.txt'), delimiter = ',')

# equivalence ratio = 0.5
data_detailed_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-detailed-1atm-phi0.5.txt'), delimiter = ',')
data_detailed_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-detailed-40atm-phi0.5.txt'), delimiter = ',')
data_drgep_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-DRGEP-1atm-phi0.5.txt'), delimiter = ',')
data_drgep_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-DRGEP-40atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_1_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-DRGEPSA-1atm-phi0.5.txt'), delimiter = ',')
data_drgepsa_40_phip5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-DRGEPSA-40atm-phi0.5.txt'), delimiter = ',')

# equivalence ratio = 1.5
data_detailed_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-detailed-1atm-phi1.5.txt'), delimiter = ',')
data_detailed_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-detailed-40atm-phi1.5.txt'), delimiter = ',')
data_drgep_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-DRGEP-1atm-phi1.5.txt'), delimiter = ',')
data_drgep_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-DRGEP-40atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_1_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-DRGEPSA-1atm-phi1.5.txt'), delimiter = ',')
data_drgepsa_40_phi1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-PSR-DRGEPSA-40atm-phi1.5.txt'), delimiter = ',')


# plot masked data to avoid clutter in lower branches
plt.semilogx(data_detailed_1[:,0],
             np.ma.masked_less(data_detailed_1[:,1], 1600),
             marker='.', linestyle='None', color='black', label='Detailed', markevery=3
             )
plt.semilogx(data_detailed_40[:,0],
             np.ma.masked_less(data_detailed_40[:,1], 1700),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phip5[:,0],
             np.ma.masked_less(data_detailed_1_phip5[:,1], 1300),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phip5[:,0],
             np.ma.masked_less(data_detailed_40_phip5[:,1], 1200),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_1_phi1p5[:,0],
             np.ma.masked_less(data_detailed_1_phi1p5[:,1], 1600),
             marker='.', linestyle='None', color='black', markevery=3
             )
plt.semilogx(data_detailed_40_phi1p5[:,0],
             np.ma.masked_less(data_detailed_40_phi1p5[:,1], 1600),
             marker='.', linestyle='None', color='black', markevery=3
             )

plt.semilogx(data_drgep_1[:,0],
             np.ma.masked_less(data_drgep_1[:,1], 1600),
             linestyle='-', color='blue', label='DRGEP'
             )
plt.semilogx(data_drgep_40[:,0],
             np.ma.masked_less(data_drgep_40[:,1], 1700),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phip5[:,0],
             np.ma.masked_less(data_drgep_1_phip5[:,1], 1300),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phip5[:,0],
             np.ma.masked_less(data_drgep_40_phip5[:,1], 1200),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_1_phi1p5[:,0],
             np.ma.masked_less(data_drgep_1_phi1p5[:,1], 1600),
             linestyle='-', color='blue'
             )
plt.semilogx(data_drgep_40_phi1p5[:,0],
             np.ma.masked_less(data_drgep_40_phi1p5[:,1], 1600),
             linestyle='-', color='blue'
             )

plt.semilogx(data_drgepsa_1[:,0],
             np.ma.masked_less(data_drgepsa_1[:,1], 1600),
             linestyle='--', color='red', label='DRGEPSA'
             )
plt.semilogx(data_drgepsa_40[:,0],
             np.ma.masked_less(data_drgepsa_40[:,1], 1700),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phip5[:,0],
             np.ma.masked_less(data_drgepsa_1_phip5[:,1], 1300),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phip5[:,0],
             np.ma.masked_less(data_drgepsa_40_phip5[:,1], 1200),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_1_phi1p5[:,0],
             np.ma.masked_less(data_drgepsa_1_phi1p5[:,1], 1600),
             linestyle='--', color='red'
             )
plt.semilogx(data_drgepsa_40_phi1p5[:,0],
             np.ma.masked_less(data_drgepsa_40_phi1p5[:,1], 1600),
             linestyle='--', color='red'
             )

plt.axis((1e-5, 0.8, 1250, 2500))

plt.text(1e-1, 2325, '$\phi$ = 1.0', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )
plt.text(1e-1, 1630, '$\phi$ = 0.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )
plt.text(1e-1, 2060, '$\phi$ = 1.5', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center'
         )

plt.annotate('1 atm', fontsize=16, color='black',
              xytext=(2e-3, 1750), xy=(2e-3, 1510),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(2e-3, 1750), xy=(4e-4, 1750),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('1 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(2e-3, 1750), xy=(1.6e-4, 1640),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

plt.annotate('40 atm', fontsize=16, color='black',
              xytext=(3e-5, 1500), xy=(3e-5, 1800),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(3e-5, 1500), xy=(1e-4, 1625),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate('40 atm', fontsize=16, color='black', alpha=0.0,
              xytext=(3e-5, 1500), xy=(3.5e-3, 1400),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='lower right', prop=leg_font, numpoints=1)
plt.xlabel('Residence time (s)', **axis_font)
plt.ylabel('Temperature (K)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Sarathy_tertbutanol_skel_PSR.pdf'))
pp.savefig()
pp.close()
