#! /usr/bin/env python
"""Plots validation of Sarathy skeletal mechanisms for n-butanol ignition delays.
"""
from __future__ import division
import sys
import os.path
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.backends.backend_pdf import PdfPages

home_dir = os.path.join(sys.path[0], '../')
home_dir = os.path.realpath(home_dir)

figures_dir = os.path.join(home_dir, 'figures')
data_dir = os.path.join(home_dir, 'data', 'Sarathy-skeletal-ignition-validation')

font = {'weight' : 'normal',
        'size' : 16,
        'family' : 'serif',
        'serif' : ['Times New Roman']}
plt.rc('font', **font)

### n-butanol
# 1000/T (1/K), 1 atm, 20 atm, 40 atm
sarathy_detailed = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-detailed.txt'), delimiter = ',')
sarathy_drgep = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-drgep.txt'), delimiter = ',')
sarathy_drgepsa = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-drgepsa.txt'), delimiter = ',')

plt.semilogy(sarathy_detailed[:,0], sarathy_detailed[:,1], marker='o', linestyle='None', color='black', label='Detailed')
plt.semilogy(sarathy_detailed[:,0], sarathy_detailed[:,2], marker='o', linestyle='None', color='black')
plt.semilogy(sarathy_detailed[:,0], sarathy_detailed[:,3], marker='o', linestyle='None', color='black')

plt.semilogy(sarathy_drgep[:,0], sarathy_drgep[:,1], linestyle='-', color='blue', label='DRGEP')
plt.semilogy(sarathy_drgep[:,0], sarathy_drgep[:,2], linestyle='-', color='blue')
plt.semilogy(sarathy_drgep[:,0], sarathy_drgep[:,3], linestyle='-', color='blue')

plt.semilogy(sarathy_drgepsa[:,0], sarathy_drgepsa[:,1], linestyle='--', color='red', label='DRGEPSA')
plt.semilogy(sarathy_drgepsa[:,0], sarathy_drgepsa[:,2], linestyle='--', color='red')
plt.semilogy(sarathy_drgepsa[:,0], sarathy_drgepsa[:,3], linestyle='--', color='red')

plt.text(0.88, 1e-2, '1 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(0.92, 1e-3, '20 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(0.94, 1.e-4, '40 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')

plt.axis((0.6, 1.02, 1.e-6, 2.e-1))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='lower right', prop=leg_font, numpoints=1)
plt.xlabel('1000 / T (1/K)', **axis_font)
plt.ylabel('Ignition delay (s)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Sarathy_nbutanol_skel_comparison.pdf'))
pp.savefig()
pp.close()

plt.clf()

### iso-butanol
# 1000/T (1/K), 1 atm, 20 atm, 40 atm
sarathy_detailed = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-detailed.txt'), delimiter = ',')
sarathy_drgep = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-drgep.txt'), delimiter = ',')
sarathy_drgepsa = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-drgepsa.txt'), delimiter = ',')

plt.semilogy(sarathy_detailed[:,0], sarathy_detailed[:,1], marker='o', linestyle='None', color='black', label='Detailed')
plt.semilogy(sarathy_detailed[:,0], sarathy_detailed[:,2], marker='o', linestyle='None', color='black')
plt.semilogy(sarathy_detailed[:,0], sarathy_detailed[:,3], marker='o', linestyle='None', color='black')

plt.semilogy(sarathy_drgep[:,0], sarathy_drgep[:,1], linestyle='-', color='blue', label='DRGEP')
plt.semilogy(sarathy_drgep[:,0], sarathy_drgep[:,2], linestyle='-', color='blue')
plt.semilogy(sarathy_drgep[:,0], sarathy_drgep[:,3], linestyle='-', color='blue')

plt.semilogy(sarathy_drgepsa[:,0], sarathy_drgepsa[:,1], linestyle='--', color='red', label='DRGEPSA')
plt.semilogy(sarathy_drgepsa[:,0], sarathy_drgepsa[:,2], linestyle='--', color='red')
plt.semilogy(sarathy_drgepsa[:,0], sarathy_drgepsa[:,3], linestyle='--', color='red')

plt.text(0.88, 1e-2, '1 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(0.92, 1e-3, '20 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(0.94, 1.e-4, '40 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')

plt.axis((0.6, 1.02, 1.e-6, 2.e-1))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='lower right', prop=leg_font, numpoints=1)
plt.xlabel('1000 / T (1/K)', **axis_font)
plt.ylabel('Ignition delay (s)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Sarathy_isobutanol_skel_comparison.pdf'))
pp.savefig()
pp.close()

plt.clf()

### sec-butanol
# 1000/T (1/K), 1 atm, 20 atm, 40 atm
sarathy_detailed = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-detailed.txt'), delimiter = ',')
sarathy_drgep = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-drgep.txt'), delimiter = ',')
sarathy_drgepsa = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-drgepsa.txt'), delimiter = ',')

plt.semilogy(sarathy_detailed[:,0], sarathy_detailed[:,1], marker='o', linestyle='None', color='black', label='Detailed')
plt.semilogy(sarathy_detailed[:,0], sarathy_detailed[:,2], marker='o', linestyle='None', color='black')
plt.semilogy(sarathy_detailed[:,0], sarathy_detailed[:,3], marker='o', linestyle='None', color='black')

plt.semilogy(sarathy_drgep[:,0], sarathy_drgep[:,1], linestyle='-', color='blue', label='DRGEP')
plt.semilogy(sarathy_drgep[:,0], sarathy_drgep[:,2], linestyle='-', color='blue')
plt.semilogy(sarathy_drgep[:,0], sarathy_drgep[:,3], linestyle='-', color='blue')

plt.semilogy(sarathy_drgepsa[:,0], sarathy_drgepsa[:,1], linestyle='--', color='red', label='DRGEPSA')
plt.semilogy(sarathy_drgepsa[:,0], sarathy_drgepsa[:,2], linestyle='--', color='red')
plt.semilogy(sarathy_drgepsa[:,0], sarathy_drgepsa[:,3], linestyle='--', color='red')

plt.text(0.88, 1e-2, '1 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(0.92, 1e-3, '20 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(0.94, 1.e-4, '40 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')

plt.axis((0.6, 1.02, 1.e-6, 2.e-1))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='lower right', prop=leg_font, numpoints=1)
plt.xlabel('1000 / T (1/K)', **axis_font)
plt.ylabel('Ignition delay (s)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Sarathy_secbutanol_skel_comparison.pdf'))
pp.savefig()
pp.close()

plt.clf()

### tert-butanol
# 1000/T (1/K), 1 atm, 20 atm, 40 atm
sarathy_detailed = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-detailed.txt'), delimiter = ',')
sarathy_drgep = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-drgep.txt'), delimiter = ',')
sarathy_drgepsa = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-drgepsa.txt'), delimiter = ',')

plt.semilogy(sarathy_detailed[:,0], sarathy_detailed[:,1], marker='o', linestyle='None', color='black', label='Detailed')
plt.semilogy(sarathy_detailed[:,0], sarathy_detailed[:,2], marker='o', linestyle='None', color='black')
plt.semilogy(sarathy_detailed[:,0], sarathy_detailed[:,3], marker='o', linestyle='None', color='black')

plt.semilogy(sarathy_drgep[:,0], sarathy_drgep[:,1], linestyle='-', color='blue', label='DRGEP')
plt.semilogy(sarathy_drgep[:,0], sarathy_drgep[:,2], linestyle='-', color='blue')
plt.semilogy(sarathy_drgep[:,0], sarathy_drgep[:,3], linestyle='-', color='blue')

plt.semilogy(sarathy_drgepsa[:,0], sarathy_drgepsa[:,1], linestyle='--', color='red', label='DRGEPSA')
plt.semilogy(sarathy_drgepsa[:,0], sarathy_drgepsa[:,2], linestyle='--', color='red')
plt.semilogy(sarathy_drgepsa[:,0], sarathy_drgepsa[:,3], linestyle='--', color='red')

plt.text(0.88, 2e-2, '1 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(0.92, 2.5e-3, '20 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(0.94, 2.e-4, '40 atm', fontsize=16, color='black',
        horizontalalignment='center', verticalalignment='center')

plt.axis((0.6, 1.02, 1.e-6, 2.e-1))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='lower right', prop=leg_font, numpoints=1)
plt.xlabel('1000 / T (1/K)', **axis_font)
plt.ylabel('Ignition delay (s)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Sarathy_tertbutanol_skel_comparison.pdf'))
pp.savefig()
pp.close()
