#! /usr/bin/env python
"""Plots butanol isomer mass fractions during engine simulation, for Sarathy mechanism.
"""
from __future__ import print_function, division
import sys
import os.path
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.backends.backend_pdf import PdfPages

home_dir = os.path.join(sys.path[0], '../')
home_dir = os.path.realpath(home_dir)

figures_dir = os.path.join(home_dir, 'figures')
data_dir = os.path.join(home_dir, 'data', 'Sarathy-engine-mass-fractions')

font = {'weight' : 'normal',
        'size' : 16,
        'family' : 'serif',
        'serif' : ['Times New Roman']}
plt.rc('font', **font)
axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}

## n-butanol
# crank angle (deg CA), mass fraction
nbutanol_detailed = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-detailed.txt'), delimiter = ',')
nbutanol_drgep = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-drgep.txt'), delimiter = ',')
nbutanol_drgepsa = np.genfromtxt(os.path.join(data_dir, 'Sarathy-nbutanol-drgepsa.txt'), delimiter = ',')

plt.plot(nbutanol_detailed[:,0], nbutanol_detailed[:,1], marker='.', linestyle='None', color='black', label='Detailed')
plt.plot(nbutanol_drgep[:,0], nbutanol_drgep[:,1], linestyle='-', color='blue', label='DRGEP')
plt.plot(nbutanol_drgepsa[:,0], nbutanol_drgepsa[:,1], linestyle='--', color='red', label='DRGEPSA')

# iso-butanol
isobutanol_detailed = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-detailed.txt'), delimiter = ',')
isobutanol_drgep = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-drgep.txt'), delimiter = ',')
isobutanol_drgepsa = np.genfromtxt(os.path.join(data_dir, 'Sarathy-isobutanol-drgepsa.txt'), delimiter = ',')

plt.plot(isobutanol_detailed[:,0], isobutanol_detailed[:,1], marker='.', linestyle='None', color='black')
plt.plot(isobutanol_drgep[:,0], isobutanol_drgep[:,1], linestyle='-', color='blue')
plt.plot(isobutanol_drgepsa[:,0], isobutanol_drgepsa[:,1], linestyle='--', color='red')

# sec-butanol
secbutanol_detailed = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-detailed.txt'), delimiter = ',')
secbutanol_drgep = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-drgep.txt'), delimiter = ',')
secbutanol_drgepsa = np.genfromtxt(os.path.join(data_dir, 'Sarathy-secbutanol-drgepsa.txt'), delimiter = ',')

plt.plot(secbutanol_detailed[:,0], secbutanol_detailed[:,1], marker='.', linestyle='None', color='black')
plt.plot(secbutanol_drgep[:,0], secbutanol_drgep[:,1], linestyle='-', color='blue')
plt.plot(secbutanol_drgepsa[:,0], secbutanol_drgepsa[:,1], linestyle='--', color='red')

# tert-butanol
tertbutanol_detailed = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-detailed.txt'), delimiter = ',')
tertbutanol_drgep = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-drgep.txt'), delimiter = ',')
tertbutanol_drgepsa = np.genfromtxt(os.path.join(data_dir, 'Sarathy-tertbutanol-drgepsa.txt'), delimiter = ',')

plt.plot(tertbutanol_detailed[:,0], tertbutanol_detailed[:,1], marker='.', linestyle='None', color='black')
plt.plot(tertbutanol_drgep[:,0], tertbutanol_drgep[:,1], linestyle='-', color='blue')
plt.plot(tertbutanol_drgepsa[:,0], tertbutanol_drgepsa[:,1], linestyle='--', color='red')

plt.axis((-20, -6, -0.001, 0.045))

plt.text(-16.5, 0.03, r'$n$-butanol', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center')
plt.annotate('isobutanol', fontsize=16, color='black',
              xy=(-14.327, 0.028), xytext=(-17, 0.02),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.annotate(r'$sec$-butanol', fontsize=16, color='black',
              xy=(-13.735, 0.0325), xytext=(-12, 0.04),
              horizontalalignment='center', verticalalignment='center',
              arrowprops=dict(arrowstyle="-"))
plt.text(-9.5, 0.03, r'$tert$-butanol', fontsize=16, color='black',
         horizontalalignment='center', verticalalignment='center')

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='upper right', prop=leg_font, numpoints=1)

plt.xlabel(r'Crank angle ($^{\circ}$CA)', **axis_font)
plt.ylabel('Fuel mass fraction', **axis_font)

plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Sarathy_engine_massfractions.pdf'))
pp.savefig()
pp.close()
