#! /usr/bin/env python
"""Plots sensitivity coefficients of laminar flame speed to various reactions, for Sarathy mechanism.
"""
from __future__ import print_function, division
import sys
import os.path
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.backends.backend_pdf import PdfPages

home_dir = os.path.join(sys.path[0], '../')
home_dir = os.path.realpath(home_dir)

figures_dir = os.path.join(home_dir, 'figures')
data_dir = os.path.join(home_dir, 'data')

font = {'weight' : 'normal',
        'size' : 16,
        'family' : 'serif',
        'serif' : ['Times New Roman']}
plt.rc('font', **font)
axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}

# reaction strings given in first column
reactions = np.genfromtxt(os.path.join(data_dir, 'Sarathy-flamespeed-sensitivity.txt'), usecols=0, delimiter=',', dtype=str)
# sensitivity coefficients for detailed, DRGEP, DRGEPSA mechanisms
data = np.genfromtxt(os.path.join(data_dir, 'Sarathy-flamespeed-sensitivity.txt'), delimiter=',')[:,1:]

fig, ax = plt.subplots()

pos = np.arange(len(data))
bar_width = 0.3

ax.barh(pos + bar_width, data[:,0], height=bar_width, align='center', color='black', label='Detailed')
rects = ax.barh(pos, data[:,1], height=bar_width, align='center', color='blue', label='DRGEP')
ax.barh(pos - bar_width, data[:,2], height=bar_width, align='center', color='red', label='DRGEPSA')

for rect in rects:
    width = rect.get_width()

    # align to either the left or right depending on if sensitivity value is
    # positive or negative
    if rect.get_x() < 0:
        align = 'left'
        xpos = 0.01
    else:
        align = 'right'
        xpos = -0.01

    ax.text(xpos, rect.get_y(), reactions[rects.index(rect)],
            verticalalignment='center', horizontalalignment=align
            )

ax.set_xlim([-0.275, 0.35])
ax.set_ylim([pos[0] - 2*bar_width, pos[-1] + 2*bar_width])
# move left spine to zero location in data space
ax.spines['left'].set_position(('data',0))
# remove right spine
ax.spines['right'].set_color('none')
# remove y tick labels
ax.get_yaxis().set_ticks([])

ax.legend(loc='center right', prop=leg_font, numpoints=1)
ax.set_xlabel('Sensitivity coefficient of laminar flame speed', **axis_font)

plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'nbutanol_flamespeed_sensitivity.pdf'))
pp.savefig()
pp.close()
