#! /usr/bin/env python
"""Plots validation of Sarathy skeletal mechanisms for n-butanol autoignition temperature
"""
from __future__ import division
import sys
import os.path
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.backends.backend_pdf import PdfPages

home_dir = os.path.join(sys.path[0], '../')
home_dir = os.path.realpath(home_dir)

figures_dir = os.path.join(home_dir, 'figures')

font = {'weight' : 'normal',
        'size' : 16,
        'family' : 'serif',
        'serif' : ['Times New Roman']}
plt.rc('font', **font)

# phi = 1.0
data_dir = os.path.join(home_dir, 'data', 'Sarathy-temperature-profile-phi-1.0')

### n-butanol
# time (s), temperature (K)
temp_det_1000 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-temperature-1000K.txt'), delimiter = ',')
temp_det_1200 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-temperature-1200K.txt'), delimiter = ',')
temp_det_1400 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-temperature-1400K.txt'), delimiter = ',')
temp_det_1600 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-temperature-1600K.txt'), delimiter = ',')

temp_drgep_1000 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEP-temperature-1000K.txt'), delimiter = ',')
temp_drgep_1200 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEP-temperature-1200K.txt'), delimiter = ',')
temp_drgep_1400 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEP-temperature-1400K.txt'), delimiter = ',')
temp_drgep_1600 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEP-temperature-1600K.txt'), delimiter = ',')

temp_drgepsa_1000 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEPSA-temperature-1000K.txt'), delimiter = ',')
temp_drgepsa_1200 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEPSA-temperature-1200K.txt'), delimiter = ',')
temp_drgepsa_1400 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEPSA-temperature-1400K.txt'), delimiter = ',')
temp_drgepsa_1600 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEPSA-temperature-1600K.txt'), delimiter = ',')

plt.semilogx(temp_det_1000[:,0], temp_det_1000[:,1], marker='.', linestyle='None', color='black', label='Detailed')
plt.semilogx(temp_det_1200[:,0], temp_det_1200[:,1], marker='.', linestyle='None', color='black')
plt.semilogx(temp_det_1400[:,0], temp_det_1400[:,1], marker='.', linestyle='None', color='black')
plt.semilogx(temp_det_1600[:,0], temp_det_1600[:,1], marker='.', linestyle='None', color='black')

plt.semilogx(temp_drgep_1000[:,0], temp_drgep_1000[:,1], linestyle='-', color='blue', label='DRGEP')
plt.semilogx(temp_drgep_1200[:,0], temp_drgep_1200[:,1], linestyle='-', color='blue')
plt.semilogx(temp_drgep_1400[:,0], temp_drgep_1400[:,1], linestyle='--', color='blue')
plt.semilogx(temp_drgep_1600[:,0], temp_drgep_1600[:,1], linestyle='-', color='blue')

plt.semilogx(temp_drgepsa_1000[:,0], temp_drgepsa_1000[:,1], linestyle='--', color='red', label='DRGEPSA')
plt.semilogx(temp_drgepsa_1200[:,0], temp_drgepsa_1200[:,1], linestyle='--', color='red')
plt.semilogx(temp_drgepsa_1400[:,0], temp_drgepsa_1400[:,1], linestyle='--', color='red')
plt.semilogx(temp_drgepsa_1600[:,0], temp_drgepsa_1600[:,1], linestyle='--', color='red')

plt.axis((1.e-8, 1.e-2, 800, 3500))

plt.text(4e-4, 1100, u'$T_0$ = 1000 K', fontsize=15, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(2.5e-5, 1300, u'$T_0$ = 1200 K', fontsize=15, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(2e-6, 1500, u'$T_0$ = 1400 K', fontsize=15, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(3e-7, 1700, u'$T_0$ = 1600 K', fontsize=15, color='black',
        horizontalalignment='center', verticalalignment='center')

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='upper left', prop=leg_font, numpoints=1)
plt.xlabel('Time (s)', **axis_font)
plt.ylabel('Temperature (K)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Sarathy_nbutanol_temperature_profile_phi1p0.pdf'))
pp.savefig()
pp.close()

plt.clf()

# phi = 0.5
data_dir = os.path.join(home_dir, 'data', 'Sarathy-temperature-profile-phi-0.5')

### n-butanol
# time (s), temperature (K)
temp_det_1000 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-temperature-1000K.txt'), delimiter = ',')
temp_det_1200 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-temperature-1200K.txt'), delimiter = ',')
temp_det_1400 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-temperature-1400K.txt'), delimiter = ',')
temp_det_1600 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-temperature-1600K.txt'), delimiter = ',')

temp_drgep_1000 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEP-temperature-1000K.txt'), delimiter = ',')
temp_drgep_1200 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEP-temperature-1200K.txt'), delimiter = ',')
temp_drgep_1400 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEP-temperature-1400K.txt'), delimiter = ',')
temp_drgep_1600 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEP-temperature-1600K.txt'), delimiter = ',')

temp_drgepsa_1000 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEPSA-temperature-1000K.txt'), delimiter = ',')
temp_drgepsa_1200 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEPSA-temperature-1200K.txt'), delimiter = ',')
temp_drgepsa_1400 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEPSA-temperature-1400K.txt'), delimiter = ',')
temp_drgepsa_1600 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-DRGEPSA-temperature-1600K.txt'), delimiter = ',')

plt.semilogx(temp_det_1000[:,0], temp_det_1000[:,1], marker='.', linestyle='None', color='black', label='Detailed')
plt.semilogx(temp_det_1200[:,0], temp_det_1200[:,1], marker='.', linestyle='None', color='black')
plt.semilogx(temp_det_1400[:,0], temp_det_1400[:,1], marker='.', linestyle='None', color='black')
plt.semilogx(temp_det_1600[:,0], temp_det_1600[:,1], marker='.', linestyle='None', color='black')

plt.semilogx(temp_drgep_1000[:,0], temp_drgep_1000[:,1], linestyle='-', color='blue', label='DRGEP')
plt.semilogx(temp_drgep_1200[:,0], temp_drgep_1200[:,1], linestyle='-', color='blue')
plt.semilogx(temp_drgep_1400[:,0], temp_drgep_1400[:,1], linestyle='--', color='blue')
plt.semilogx(temp_drgep_1600[:,0], temp_drgep_1600[:,1], linestyle='-', color='blue')

plt.semilogx(temp_drgepsa_1000[:,0], temp_drgepsa_1000[:,1], linestyle='--', color='red', label='DRGEPSA')
plt.semilogx(temp_drgepsa_1200[:,0], temp_drgepsa_1200[:,1], linestyle='--', color='red')
plt.semilogx(temp_drgepsa_1400[:,0], temp_drgepsa_1400[:,1], linestyle='--', color='red')
plt.semilogx(temp_drgepsa_1600[:,0], temp_drgepsa_1600[:,1], linestyle='--', color='red')

plt.axis((1.e-8, 1.e-2, 800, 3500))

plt.text(4e-4, 1100, u'$T_0$ = 1000 K', fontsize=15, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(2.5e-5, 1300, u'$T_0$ = 1200 K', fontsize=15, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(2e-6, 1500, u'$T_0$ = 1400 K', fontsize=15, color='black',
        horizontalalignment='center', verticalalignment='center')
plt.text(3e-7, 1700, u'$T_0$ = 1600 K', fontsize=15, color='black',
        horizontalalignment='center', verticalalignment='center')

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}
plt.legend(loc='upper left', prop=leg_font, numpoints=1)
plt.xlabel('Time (s)', **axis_font)
plt.ylabel('Temperature (K)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'Sarathy_nbutanol_temperature_profile_phi0p5.pdf'))
pp.savefig()
pp.close()
