#! /usr/bin/env python
"""Plots comparison of butanol isomers experimental and simulated laminar flame speeds.
"""
from __future__ import division
import sys
import os.path
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.backends.backend_pdf import PdfPages

home_dir = os.path.join(sys.path[0], '../')
home_dir = os.path.realpath(home_dir)

figures_dir = os.path.join(home_dir, 'figures')
data_dir = os.path.join(home_dir, 'data', 'laminar-flame-exp')

font = {'weight' : 'normal',
        'size' : 16,
        'family' : 'serif',
        'serif' : ['Times New Roman']}
plt.rc('font', **font)
axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}

## n-butanol

# experimental data
# equivalence ratio, flame speed [cm/s]
exp_data = np.genfromtxt(os.path.join(data_dir, 'nbutanol-flamespeed-Veloo.txt'), delimiter = ',')
# simulated results
# equivalence ratio, flame speed [cm/s]
sim_data = np.genfromtxt(os.path.join(data_dir, 'nbutanol-flamespeed-simulated.txt'), delimiter = ',')

plt.plot(exp_data[:,0], exp_data[:,1], marker='o', linestyle='None', color='blue', label='Experiment')
plt.plot(sim_data[:,0], sim_data[:,1], linestyle='-', color='black', label='Sarathy detailed')
plt.plot(sim_data[:,0], sim_data[:,2], linestyle='--', color='green', label='Merchant detailed')

plt.axis((0.55,1.65,0.0,70.))
plt.legend(loc='lower center', prop=leg_font, numpoints=1)
plt.xlabel('Equivalence ratio', **axis_font)
plt.ylabel('Laminar flame speed (cm/s)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'nbutanol_exp_comp_flamespeed.pdf'))
pp.savefig()
pp.close()

plt.clf()

## iso-butanol

# experimental data
# equivalence ratio, flame speed [cm/s]
exp_data = np.genfromtxt(os.path.join(data_dir, 'isobutanol-flamespeed-Veloo.txt'), delimiter = ',')
# simulated results
# equivalence ratio, flame speed [cm/s]
sim_data = np.genfromtxt(os.path.join(data_dir, 'isobutanol-flamespeed-simulated.txt'), delimiter = ',')

plt.plot(exp_data[:,0], exp_data[:,1], marker='o', linestyle='None', color='blue', label='Experiment')
plt.plot(sim_data[:,0], sim_data[:,1], linestyle='-', color='black', label='Sarathy detailed')
plt.plot(sim_data[:,0], sim_data[:,2], linestyle='--', color='green', label='Merchant detailed')

plt.axis((0.55,1.65,0.0,70.))
plt.legend(loc='lower center', prop=leg_font, numpoints=1)
plt.xlabel('Equivalence ratio', **axis_font)
plt.ylabel('Laminar flame speed (cm/s)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'isobutanol_exp_comp_flamespeed.pdf'))
pp.savefig()
pp.close()

plt.clf()

## sec-butanol

# experimental data
# equivalence ratio, flame speed [cm/s]
exp_data = np.genfromtxt(os.path.join(data_dir, 'secbutanol-flamespeed-Veloo.txt'), delimiter = ',')
# simulated results
# equivalence ratio, flame speed [cm/s]
sim_data = np.genfromtxt(os.path.join(data_dir, 'secbutanol-flamespeed-simulated.txt'), delimiter = ',')

plt.plot(exp_data[:,0], exp_data[:,1], marker='o', linestyle='None', color='blue', label='Experiment')
plt.plot(sim_data[:,0], sim_data[:,1], linestyle='-', color='black', label='Sarathy detailed')
plt.plot(sim_data[:,0], sim_data[:,2], linestyle='--', color='green', label='Merchant detailed')

plt.axis((0.55,1.65,0.0,70.))
plt.legend(loc='lower center', prop=leg_font, numpoints=1)
plt.xlabel('Equivalence ratio', **axis_font)
plt.ylabel('Laminar flame speed (cm/s)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'secbutanol_exp_comp_flamespeed.pdf'))
pp.savefig()
pp.close()

plt.clf()

## tert-butanol

# experimental data
# equivalence ratio, flame speed [cm/s]
exp_data = np.genfromtxt(os.path.join(data_dir, 'tertbutanol-flamespeed-Veloo.txt'), delimiter = ',')
# simulated results
# equivalence ratio, flame speed [cm/s]
sim_data = np.genfromtxt(os.path.join(data_dir, 'tertbutanol-flamespeed-simulated.txt'), delimiter = ',')

plt.plot(exp_data[:,0], exp_data[:,1], marker='o', linestyle='None', color='blue', label='Experiment')
plt.plot(sim_data[:,0], sim_data[:,1], linestyle='-', color='black', label='Sarathy detailed')
plt.plot(sim_data[:,0], sim_data[:,2], linestyle='--', color='green', label='Merchant detailed')

plt.axis((0.55,1.65,0.0,70.))
plt.legend(loc='lower center', prop=leg_font, numpoints=1)
plt.xlabel('Equivalence ratio', **axis_font)
plt.ylabel('Laminar flame speed (cm/s)', **axis_font)
plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'tertbutanol_exp_comp_flamespeed.pdf'))
pp.savefig()
pp.close()

plt.clf()
