#! /usr/bin/env python
"""Plots comparison of tert-butanol experimental and simulated ignition delays.
"""
from __future__ import division
import sys
import os.path
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.backends.backend_pdf import PdfPages

home_dir = os.path.join(sys.path[0], '../')
home_dir = os.path.realpath(home_dir)

figures_dir = os.path.join(home_dir, 'figures')
data_dir = os.path.join(home_dir, 'data', 'tertbutanol-autoignition-exp')

font = {'weight' : 'normal',
        'size' : 16,
        'family' : 'serif',
        'serif' : ['Times New Roman']}
plt.rc('font', **font)

# experimental data
# 1000/T [K^-1], tau [second]
exp_data_1p5 = np.genfromtxt(os.path.join(data_dir, 'Stranic-1.5atm.txt'), delimiter = ',')
exp_data_3 = np.genfromtxt(os.path.join(data_dir, 'Stranic-3atm.txt'), delimiter = ',')
exp_data_19 = np.genfromtxt(os.path.join(data_dir, 'Stranic-19atm.txt'), delimiter = ',')
exp_data_43 = np.genfromtxt(os.path.join(data_dir, 'Stranic-43atm.txt'), delimiter = ',')

# Sarathy mechanism results
# 1000/T [K^-1], tau [second]
sarathy_data_1p5 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-1.5atm.txt'), delimiter = ',')
sarathy_data_3 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-3atm.txt'), delimiter = ',')
sarathy_data_19 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-19atm.txt'), delimiter = ',')
sarathy_data_43 = np.genfromtxt(os.path.join(data_dir, 'Sarathy-43atm.txt'), delimiter = ',')

# Merchant mechanism results
# 1000/T [K^-1], tau [second]
merchant_data_1p5 = np.genfromtxt(os.path.join(data_dir, 'Merchant-1.5atm.txt'), delimiter = ',')
merchant_data_3 = np.genfromtxt(os.path.join(data_dir, 'Merchant-3atm.txt'), delimiter = ',')
merchant_data_19 = np.genfromtxt(os.path.join(data_dir, 'Merchant-19atm.txt'), delimiter = ',')
merchant_data_43 = np.genfromtxt(os.path.join(data_dir, 'Merchant-43atm.txt'), delimiter = ',')

plt.semilogy(exp_data_1p5[:,0], exp_data_1p5[:,1], marker='o', linestyle='None', color='red')
plt.semilogy(exp_data_3[:,0], exp_data_3[:,1], marker='s', linestyle='None', color='blue')
plt.semilogy(exp_data_19[:,0], exp_data_19[:,1], marker='d', linestyle='None', color='green')
plt.semilogy(exp_data_43[:,0], exp_data_43[:,1], marker='^', linestyle='None', color='black')

plt.semilogy(sarathy_data_1p5[:,0], sarathy_data_1p5[:,1], linestyle='-', color='red')
plt.semilogy(sarathy_data_3[:,0], sarathy_data_3[:,1], linestyle='-', color='blue')
plt.semilogy(sarathy_data_19[:,0], sarathy_data_19[:,1], linestyle='-', color='green')
plt.semilogy(sarathy_data_43[:,0], sarathy_data_43[:,1], linestyle='-',
             color='black', label='Sarathy detailed'
             )

plt.semilogy(merchant_data_1p5[:,0], merchant_data_1p5[:,1], linestyle='--', color='red')
plt.semilogy(merchant_data_3[:,0], merchant_data_3[:,1], linestyle='--', color='blue')
plt.semilogy(merchant_data_19[:,0], merchant_data_19[:,1], linestyle='--', color='green')
plt.semilogy(merchant_data_43[:,0], merchant_data_43[:,1], linestyle='--',
             color='black', label='Merchant detailed'
             )

plt.text(0.68, 1.3e-3, '1.5 atm', fontsize=16, color='red',
        horizontalalignment='center', verticalalignment='center')
plt.text(0.75, 2.e-3, '3 atm', fontsize=16, color='blue',
        horizontalalignment='center', verticalalignment='center')
plt.text(0.805, 2.e-3, '19 atm', fontsize=16, color='green',
        horizontalalignment='center', verticalalignment='center')
plt.text(0.86, 1.e-3, '43 atm', fontsize=16,
        horizontalalignment='center', verticalalignment='center')

plt.axis((0.58,0.9,3.e-5,5.e-3))

axis_font = {'fontname':'Times New Roman', 'size':'20'}
leg_font = {'family':'serif', 'size':'16'}

plt.legend(loc='lower right', prop=leg_font)

plt.xlabel('1000 / T (1/K)', **axis_font)
plt.ylabel('Ignition delay (s)', **axis_font)

plt.show()

# save to file
pp = PdfPages(os.path.join(figures_dir, 'tertbutanol_exp_comparison.pdf'))
pp.savefig()
pp.close()
